"""AUTOGENERATED. DO NOT EDIT."""

from tf_keras.api._v1.keras.optimizers import legacy
from tf_keras.api._v1.keras.optimizers import schedules
from tf_keras.src.optimizers import deserialize
from tf_keras.src.optimizers import get
from tf_keras.src.optimizers import serialize
from tf_keras.src.optimizers.legacy.adadelta import Adadelta
from tf_keras.src.optimizers.legacy.adagrad import Adagrad
from tf_keras.src.optimizers.legacy.adam import Adam
from tf_keras.src.optimizers.legacy.adamax import Adamax
from tf_keras.src.optimizers.legacy.ftrl import Ftrl
from tf_keras.src.optimizers.legacy.gradient_descent import SGD
from tf_keras.src.optimizers.legacy.nadam import Nadam
from tf_keras.src.optimizers.legacy.optimizer_v2 import OptimizerV2 as Optimizer
from tf_keras.src.optimizers.legacy.rmsprop import RMSprop
